vectorizer

package module
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 2, 2026 License: Apache-2.0 Imports: 20 Imported by: 0

README

Go API client for vectorizer

OpenAPI 3.0 specification for the Vectorizer.AI image vectorization API. Authenticate with HTTP Basic auth, using your API Id as the username and your API Secret as the password.

Overview

This API client was generated by the OpenAPI Generator project. By using the OpenAPI-spec from a remote server, you can easily generate an API client.

  • API version: 1.0.0
  • Package version: 1.0.0
  • Generator version: 7.6.0
  • Build package: org.openapitools.codegen.languages.GoClientCodegen For more information, please visit https://vectorizer.ai/support

Installation

Install the following dependencies:

go get github.com/stretchr/testify/assert
go get golang.org/x/net/context

Put the package under your project folder and add the following in import:

import vectorizer "github.com/clv/vectorizer-go"

To use a proxy, set the environment variable HTTP_PROXY:

os.Setenv("HTTP_PROXY", "http://proxy_name:proxy_port")

Configuration of Server URL

Default configuration comes with Servers field that contains server objects as defined in the OpenAPI specification.

Select Server Configuration

For using other server than the one defined on index 0 set context value vectorizer.ContextServerIndex of type int.

ctx := context.WithValue(context.Background(), vectorizer.ContextServerIndex, 1)
Templated Server URL

Templated server URL is formatted using default variables from configuration or from context value vectorizer.ContextServerVariables of type map[string]string.

ctx := context.WithValue(context.Background(), vectorizer.ContextServerVariables, map[string]string{
	"basePath": "v2",
})

Note, enum values are always validated and all unused variables are silently ignored.

URLs Configuration per Operation

Each operation can use different server URL defined using OperationServers map in the Configuration. An operation is uniquely identified by "{classname}Service.{nickname}" string. Similar rules for overriding default operation server index and variables applies by using vectorizer.ContextOperationServerIndices and vectorizer.ContextOperationServerVariables context maps.

ctx := context.WithValue(context.Background(), vectorizer.ContextOperationServerIndices, map[string]int{
	"{classname}Service.{nickname}": 2,
})
ctx = context.WithValue(context.Background(), vectorizer.ContextOperationServerVariables, map[string]map[string]string{
	"{classname}Service.{nickname}": {
		"port": "8443",
	},
})

Documentation for API Endpoints

All URIs are relative to https://api.vectorizer.ai/api/v1

Class Method HTTP request Description
AccountAPI GetAccountStatus Get /account Get account status
VectorizationAPI PostDelete Post /delete Delete a retained image
VectorizationAPI PostDownload Post /download Download a retained result
VectorizationAPI PostVectorize Post /vectorize Vectorize an image

Documentation For Models

Documentation For Authorization

Authentication schemes defined for the API:

basicAuth
  • Type: HTTP basic authentication

Example

auth := context.WithValue(context.Background(), vectorizer.ContextBasicAuth, vectorizer.BasicAuth{
	UserName: "username",
	Password: "password",
})
r, err := client.Service.Operation(auth, args)

Documentation for Utility Methods

Due to the fact that model structure members are all pointers, this package contains a number of utility functions to easily obtain pointers to values of basic types. Each of these functions takes a value of the given basic type and returns a pointer to it:

  • PtrBool
  • PtrInt
  • PtrInt32
  • PtrInt64
  • PtrFloat
  • PtrFloat32
  • PtrFloat64
  • PtrString
  • PtrTime

Author

support@vectorizer.ai

Documentation

Index

Constants

This section is empty.

Variables

var (
	JsonCheck = regexp.MustCompile(`(?i:(?:application|text)/(?:[^;]+\+)?json)`)
	XmlCheck  = regexp.MustCompile(`(?i:(?:application|text)/(?:[^;]+\+)?xml)`)
)
var (
	// ContextBasicAuth takes BasicAuth as authentication for the request.
	ContextBasicAuth = contextKey("basic")

	// ContextServerIndex uses a server configuration from the index.
	ContextServerIndex = contextKey("serverIndex")

	// ContextOperationServerIndices uses a server configuration from the index mapping.
	ContextOperationServerIndices = contextKey("serverOperationIndices")

	// ContextServerVariables overrides a server configuration variables.
	ContextServerVariables = contextKey("serverVariables")

	// ContextOperationServerVariables overrides a server configuration variables using operation specific values.
	ContextOperationServerVariables = contextKey("serverOperationVariables")
)

Functions

func CacheExpires

func CacheExpires(r *http.Response) time.Time

CacheExpires helper function to determine remaining time before repeating a request.

func IsNil

func IsNil(i interface{}) bool

IsNil checks if an input is nil

func PtrBool

func PtrBool(v bool) *bool

PtrBool is a helper routine that returns a pointer to given boolean value.

func PtrFloat32

func PtrFloat32(v float32) *float32

PtrFloat32 is a helper routine that returns a pointer to given float value.

func PtrFloat64

func PtrFloat64(v float64) *float64

PtrFloat64 is a helper routine that returns a pointer to given float value.

func PtrInt

func PtrInt(v int) *int

PtrInt is a helper routine that returns a pointer to given integer value.

func PtrInt32

func PtrInt32(v int32) *int32

PtrInt32 is a helper routine that returns a pointer to given integer value.

func PtrInt64

func PtrInt64(v int64) *int64

PtrInt64 is a helper routine that returns a pointer to given integer value.

func PtrString

func PtrString(v string) *string

PtrString is a helper routine that returns a pointer to given string value.

func PtrTime

func PtrTime(v time.Time) *time.Time

PtrTime is helper routine that returns a pointer to given Time value.

Types

type APIClient

type APIClient struct {
	AccountAPI *AccountAPIService

	VectorizationAPI *VectorizationAPIService
	// contains filtered or unexported fields
}

APIClient manages communication with the Vectorizer.AI API API v1.0.0 In most cases there should be only one, shared, APIClient.

func NewAPIClient

func NewAPIClient(cfg *Configuration) *APIClient

NewAPIClient creates a new API client. Requires a userAgent string describing your application. optionally a custom http.Client to allow for advanced features such as caching.

func (*APIClient) GetConfig

func (c *APIClient) GetConfig() *Configuration

Allow modification of underlying config for alternate implementations and testing Caution: modifying the configuration while live can cause data races and potentially unwanted behavior

type APIKey

type APIKey struct {
	Key    string
	Prefix string
}

APIKey provides API key based authentication to a request passed via context using ContextAPIKey

type APIResponse

type APIResponse struct {
	*http.Response `json:"-"`
	Message        string `json:"message,omitempty"`
	// Operation is the name of the OpenAPI operation.
	Operation string `json:"operation,omitempty"`
	// RequestURL is the request URL. This value is always available, even if the
	// embedded *http.Response is nil.
	RequestURL string `json:"url,omitempty"`
	// Method is the HTTP method used for the request.  This value is always
	// available, even if the embedded *http.Response is nil.
	Method string `json:"method,omitempty"`
	// Payload holds the contents of the response body (which may be nil or empty).
	// This is provided here as the raw response.Body() reader will have already
	// been drained.
	Payload []byte `json:"-"`
}

APIResponse stores the API response returned by the server.

func NewAPIResponse

func NewAPIResponse(r *http.Response) *APIResponse

NewAPIResponse returns a new APIResponse object.

func NewAPIResponseWithError

func NewAPIResponseWithError(errorMessage string) *APIResponse

NewAPIResponseWithError returns a new APIResponse object with the provided error message.

type AccountAPIService

type AccountAPIService service

AccountAPIService AccountAPI service

func (*AccountAPIService) GetAccountStatus

GetAccountStatus Get account status

Fetch the subscription state and remaining API credits for the authenticated account.

@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
@return ApiGetAccountStatusRequest

func (*AccountAPIService) GetAccountStatusExecute

Execute executes the request

@return AccountStatusResponse

type AccountStatusResponse

type AccountStatusResponse struct {
	// The subscription plan currently associated with the account, or 'none'.
	SubscriptionPlan string `json:"subscriptionPlan"`
	// The current subscription state: 'active', 'pastDue', or 'ended'.
	SubscriptionState string `json:"subscriptionState"`
	// The number of API credits left. Can be fractional, so parse as a double-precision number.
	Credits float64 `json:"credits"`
}

AccountStatusResponse struct for AccountStatusResponse

func NewAccountStatusResponse

func NewAccountStatusResponse(subscriptionPlan string, subscriptionState string, credits float64) *AccountStatusResponse

NewAccountStatusResponse instantiates a new AccountStatusResponse object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewAccountStatusResponseWithDefaults

func NewAccountStatusResponseWithDefaults() *AccountStatusResponse

NewAccountStatusResponseWithDefaults instantiates a new AccountStatusResponse object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*AccountStatusResponse) GetCredits

func (o *AccountStatusResponse) GetCredits() float64

GetCredits returns the Credits field value

func (*AccountStatusResponse) GetCreditsOk

func (o *AccountStatusResponse) GetCreditsOk() (*float64, bool)

GetCreditsOk returns a tuple with the Credits field value and a boolean to check if the value has been set.

func (*AccountStatusResponse) GetSubscriptionPlan

func (o *AccountStatusResponse) GetSubscriptionPlan() string

GetSubscriptionPlan returns the SubscriptionPlan field value

func (*AccountStatusResponse) GetSubscriptionPlanOk

func (o *AccountStatusResponse) GetSubscriptionPlanOk() (*string, bool)

GetSubscriptionPlanOk returns a tuple with the SubscriptionPlan field value and a boolean to check if the value has been set.

func (*AccountStatusResponse) GetSubscriptionState

func (o *AccountStatusResponse) GetSubscriptionState() string

GetSubscriptionState returns the SubscriptionState field value

func (*AccountStatusResponse) GetSubscriptionStateOk

func (o *AccountStatusResponse) GetSubscriptionStateOk() (*string, bool)

GetSubscriptionStateOk returns a tuple with the SubscriptionState field value and a boolean to check if the value has been set.

func (AccountStatusResponse) MarshalJSON

func (o AccountStatusResponse) MarshalJSON() ([]byte, error)

func (*AccountStatusResponse) SetCredits

func (o *AccountStatusResponse) SetCredits(v float64)

SetCredits sets field value

func (*AccountStatusResponse) SetSubscriptionPlan

func (o *AccountStatusResponse) SetSubscriptionPlan(v string)

SetSubscriptionPlan sets field value

func (*AccountStatusResponse) SetSubscriptionState

func (o *AccountStatusResponse) SetSubscriptionState(v string)

SetSubscriptionState sets field value

func (AccountStatusResponse) ToMap

func (o AccountStatusResponse) ToMap() (map[string]interface{}, error)

func (*AccountStatusResponse) UnmarshalJSON

func (o *AccountStatusResponse) UnmarshalJSON(data []byte) (err error)

type ApiGetAccountStatusRequest

type ApiGetAccountStatusRequest struct {
	ApiService *AccountAPIService
	// contains filtered or unexported fields
}

func (ApiGetAccountStatusRequest) Execute

type ApiPostDeleteRequest

type ApiPostDeleteRequest struct {
	ApiService *VectorizationAPIService
	// contains filtered or unexported fields
}

func (ApiPostDeleteRequest) Execute

func (ApiPostDeleteRequest) ImageToken

func (r ApiPostDeleteRequest) ImageToken(imageToken string) ApiPostDeleteRequest

Image Token to delete before its retention period expires.

type ApiPostDownloadRequest

type ApiPostDownloadRequest struct {
	ApiService *VectorizationAPIService
	// contains filtered or unexported fields
}

func (ApiPostDownloadRequest) Execute

func (r ApiPostDownloadRequest) Execute() (*os.File, *http.Response, error)

func (ApiPostDownloadRequest) ImageToken

func (r ApiPostDownloadRequest) ImageToken(imageToken string) ApiPostDownloadRequest

Image Token returned from a vectorize request with policy.retention_days > 0.

func (ApiPostDownloadRequest) OutputBitmapAntiAliasingMode

func (r ApiPostDownloadRequest) OutputBitmapAntiAliasingMode(outputBitmapAntiAliasingMode string) ApiPostDownloadRequest

Anti-aliasing mode for bitmap (PNG) output.

func (ApiPostDownloadRequest) OutputCurvesAllowedCircularArc

func (r ApiPostDownloadRequest) OutputCurvesAllowedCircularArc(outputCurvesAllowedCircularArc bool) ApiPostDownloadRequest

Allow circular arcs in the output.

func (ApiPostDownloadRequest) OutputCurvesAllowedCubicBezier

func (r ApiPostDownloadRequest) OutputCurvesAllowedCubicBezier(outputCurvesAllowedCubicBezier bool) ApiPostDownloadRequest

Allow cubic Bézier curves in the output.

func (ApiPostDownloadRequest) OutputCurvesAllowedEllipticalArc

func (r ApiPostDownloadRequest) OutputCurvesAllowedEllipticalArc(outputCurvesAllowedEllipticalArc bool) ApiPostDownloadRequest

Allow elliptical arcs in the output.

func (ApiPostDownloadRequest) OutputCurvesAllowedQuadraticBezier

func (r ApiPostDownloadRequest) OutputCurvesAllowedQuadraticBezier(outputCurvesAllowedQuadraticBezier bool) ApiPostDownloadRequest

Allow quadratic Bézier curves in the output.

func (ApiPostDownloadRequest) OutputCurvesLineFitTolerance

func (r ApiPostDownloadRequest) OutputCurvesLineFitTolerance(outputCurvesLineFitTolerance float32) ApiPostDownloadRequest

Maximum allowed error when approximating curves with line segments.

func (ApiPostDownloadRequest) OutputDrawStyle

func (r ApiPostDownloadRequest) OutputDrawStyle(outputDrawStyle string) ApiPostDownloadRequest

How shapes are rendered.

func (ApiPostDownloadRequest) OutputDxfCompatibilityLevel

func (r ApiPostDownloadRequest) OutputDxfCompatibilityLevel(outputDxfCompatibilityLevel string) ApiPostDownloadRequest

Level of primitive support for DXF output.

func (ApiPostDownloadRequest) OutputEpsVersion

func (r ApiPostDownloadRequest) OutputEpsVersion(outputEpsVersion string) ApiPostDownloadRequest

EPS format version for EPS output.

func (ApiPostDownloadRequest) OutputFileFormat

func (r ApiPostDownloadRequest) OutputFileFormat(outputFileFormat string) ApiPostDownloadRequest

Output file format to generate.

func (ApiPostDownloadRequest) OutputGapFillerClip

func (r ApiPostDownloadRequest) OutputGapFillerClip(outputGapFillerClip bool) ApiPostDownloadRequest

Clip gap filler strokes to shape bounds when stacking shapes.

func (ApiPostDownloadRequest) OutputGapFillerEnabled

func (r ApiPostDownloadRequest) OutputGapFillerEnabled(outputGapFillerEnabled bool) ApiPostDownloadRequest

Enable filling small visual gaps caused by vector rendering artifacts.

func (ApiPostDownloadRequest) OutputGapFillerNonScalingStroke

func (r ApiPostDownloadRequest) OutputGapFillerNonScalingStroke(outputGapFillerNonScalingStroke bool) ApiPostDownloadRequest

Use non-scaling strokes for gap filling.

func (ApiPostDownloadRequest) OutputGapFillerStrokeWidth

func (r ApiPostDownloadRequest) OutputGapFillerStrokeWidth(outputGapFillerStrokeWidth float32) ApiPostDownloadRequest

Width of the gap filler strokes (in output units).

func (ApiPostDownloadRequest) OutputGroupBy

func (r ApiPostDownloadRequest) OutputGroupBy(outputGroupBy string) ApiPostDownloadRequest

Grouping of shapes in output.

func (ApiPostDownloadRequest) OutputParameterizedShapesFlatten

func (r ApiPostDownloadRequest) OutputParameterizedShapesFlatten(outputParameterizedShapesFlatten bool) ApiPostDownloadRequest

Whether to flatten detected circles, rectangles, and stars to curves.

func (ApiPostDownloadRequest) OutputPdfCompressionMode

func (r ApiPostDownloadRequest) OutputPdfCompressionMode(outputPdfCompressionMode string) ApiPostDownloadRequest

Compression method to apply to PDF output streams.

func (ApiPostDownloadRequest) OutputPdfVersion

func (r ApiPostDownloadRequest) OutputPdfVersion(outputPdfVersion string) ApiPostDownloadRequest

PDF version to generate for PDF output.

func (ApiPostDownloadRequest) OutputShapeStacking

func (r ApiPostDownloadRequest) OutputShapeStacking(outputShapeStacking string) ApiPostDownloadRequest

Whether shapes are cut out of each other or stacked atop each other.

func (ApiPostDownloadRequest) OutputSizeAlignX

func (r ApiPostDownloadRequest) OutputSizeAlignX(outputSizeAlignX float32) ApiPostDownloadRequest

Horizontal alignment (0.0 = left, 0.5 = center, 1.0 = right) when aspect ratio is preserved.

func (ApiPostDownloadRequest) OutputSizeAlignY

func (r ApiPostDownloadRequest) OutputSizeAlignY(outputSizeAlignY float32) ApiPostDownloadRequest

Vertical alignment (0.0 = top, 0.5 = center, 1.0 = bottom) when aspect ratio is preserved.

func (ApiPostDownloadRequest) OutputSizeAspectRatio

func (r ApiPostDownloadRequest) OutputSizeAspectRatio(outputSizeAspectRatio string) ApiPostDownloadRequest

How to preserve or stretch aspect ratio.

func (ApiPostDownloadRequest) OutputSizeHeight

func (r ApiPostDownloadRequest) OutputSizeHeight(outputSizeHeight float32) ApiPostDownloadRequest

Output height, in the selected unit (see output.size.unit).

func (ApiPostDownloadRequest) OutputSizeInputDpi

func (r ApiPostDownloadRequest) OutputSizeInputDpi(outputSizeInputDpi float32) ApiPostDownloadRequest

Override the detected DPI of the input image for size computations.

func (ApiPostDownloadRequest) OutputSizeOutputDpi

func (r ApiPostDownloadRequest) OutputSizeOutputDpi(outputSizeOutputDpi float32) ApiPostDownloadRequest

DPI setting for the output image.

func (ApiPostDownloadRequest) OutputSizeScale

func (r ApiPostDownloadRequest) OutputSizeScale(outputSizeScale float32) ApiPostDownloadRequest

Overall uniform scaling factor for the output image.

func (ApiPostDownloadRequest) OutputSizeUnit

func (r ApiPostDownloadRequest) OutputSizeUnit(outputSizeUnit string) ApiPostDownloadRequest

Measurement unit for output dimensions.

func (ApiPostDownloadRequest) OutputSizeWidth

func (r ApiPostDownloadRequest) OutputSizeWidth(outputSizeWidth float32) ApiPostDownloadRequest

Output width, in the selected unit (see output.size.unit).

func (ApiPostDownloadRequest) OutputStrokesNonScalingStroke

func (r ApiPostDownloadRequest) OutputStrokesNonScalingStroke(outputStrokesNonScalingStroke bool) ApiPostDownloadRequest

Use non-scaling strokes when drawing shape outlines.

func (ApiPostDownloadRequest) OutputStrokesOverrideColor

func (r ApiPostDownloadRequest) OutputStrokesOverrideColor(outputStrokesOverrideColor string) ApiPostDownloadRequest

Color value to override shape stroke color if enabled. Must be in '#RRGGBB' or 'rgba(r,g,b,a)' format.

func (ApiPostDownloadRequest) OutputStrokesStrokeWidth

func (r ApiPostDownloadRequest) OutputStrokesStrokeWidth(outputStrokesStrokeWidth float32) ApiPostDownloadRequest

Width of stroke for shape outlines (when enabled).

func (ApiPostDownloadRequest) OutputStrokesUseOverrideColor

func (r ApiPostDownloadRequest) OutputStrokesUseOverrideColor(outputStrokesUseOverrideColor bool) ApiPostDownloadRequest

Override shape color with a specific color.

func (ApiPostDownloadRequest) OutputSvgAdobeCompatibilityMode

func (r ApiPostDownloadRequest) OutputSvgAdobeCompatibilityMode(outputSvgAdobeCompatibilityMode bool) ApiPostDownloadRequest

Enable Illustrator compatibility by disabling unsupported SVG features.

func (ApiPostDownloadRequest) OutputSvgFixedSize

func (r ApiPostDownloadRequest) OutputSvgFixedSize(outputSvgFixedSize bool) ApiPostDownloadRequest

Whether to fix the SVG dimensions in the output file.

func (ApiPostDownloadRequest) OutputSvgVersion

func (r ApiPostDownloadRequest) OutputSvgVersion(outputSvgVersion string) ApiPostDownloadRequest

SVG version to declare in the SVG output.

func (ApiPostDownloadRequest) Receipt

Receipt returned in the X-Receipt response header when upgrading a preview result to production. Include it when downloading additional formats from that upgraded preview.

type ApiPostVectorizeRequest

type ApiPostVectorizeRequest struct {
	ApiService *VectorizationAPIService
	// contains filtered or unexported fields
}

func (ApiPostVectorizeRequest) Execute

func (r ApiPostVectorizeRequest) Execute() (*os.File, *http.Response, error)

func (ApiPostVectorizeRequest) Image

Binary file upload of the image to vectorize. Accepts .bmp, .gif, .jpeg, .png, or .tiff files.

func (ApiPostVectorizeRequest) ImageBase64

func (r ApiPostVectorizeRequest) ImageBase64(imageBase64 string) ApiPostVectorizeRequest

Base64-encoded string of the input image. Maximum size 1 megabyte.

func (ApiPostVectorizeRequest) ImageToken

func (r ApiPostVectorizeRequest) ImageToken(imageToken string) ApiPostVectorizeRequest

An Image Token returned from an earlier vectorization call with policy.retention_days > 0.

func (ApiPostVectorizeRequest) ImageUrl

URL to fetch the input image from for vectorization.

func (ApiPostVectorizeRequest) InputMaxPixels

func (r ApiPostVectorizeRequest) InputMaxPixels(inputMaxPixels int32) ApiPostVectorizeRequest

Maximum input image size (width × height in pixels) before resizing.

func (ApiPostVectorizeRequest) Mode

Mode of operation, useful during integration work.

func (ApiPostVectorizeRequest) OutputBitmapAntiAliasingMode

func (r ApiPostVectorizeRequest) OutputBitmapAntiAliasingMode(outputBitmapAntiAliasingMode string) ApiPostVectorizeRequest

Anti-aliasing mode for bitmap (PNG) output.

func (ApiPostVectorizeRequest) OutputCurvesAllowedCircularArc

func (r ApiPostVectorizeRequest) OutputCurvesAllowedCircularArc(outputCurvesAllowedCircularArc bool) ApiPostVectorizeRequest

Allow circular arcs in the output.

func (ApiPostVectorizeRequest) OutputCurvesAllowedCubicBezier

func (r ApiPostVectorizeRequest) OutputCurvesAllowedCubicBezier(outputCurvesAllowedCubicBezier bool) ApiPostVectorizeRequest

Allow cubic Bézier curves in the output.

func (ApiPostVectorizeRequest) OutputCurvesAllowedEllipticalArc

func (r ApiPostVectorizeRequest) OutputCurvesAllowedEllipticalArc(outputCurvesAllowedEllipticalArc bool) ApiPostVectorizeRequest

Allow elliptical arcs in the output.

func (ApiPostVectorizeRequest) OutputCurvesAllowedQuadraticBezier

func (r ApiPostVectorizeRequest) OutputCurvesAllowedQuadraticBezier(outputCurvesAllowedQuadraticBezier bool) ApiPostVectorizeRequest

Allow quadratic Bézier curves in the output.

func (ApiPostVectorizeRequest) OutputCurvesLineFitTolerance

func (r ApiPostVectorizeRequest) OutputCurvesLineFitTolerance(outputCurvesLineFitTolerance float32) ApiPostVectorizeRequest

Maximum allowed error when approximating curves with line segments.

func (ApiPostVectorizeRequest) OutputDrawStyle

func (r ApiPostVectorizeRequest) OutputDrawStyle(outputDrawStyle string) ApiPostVectorizeRequest

How shapes are rendered.

func (ApiPostVectorizeRequest) OutputDxfCompatibilityLevel

func (r ApiPostVectorizeRequest) OutputDxfCompatibilityLevel(outputDxfCompatibilityLevel string) ApiPostVectorizeRequest

Level of primitive support for DXF output.

func (ApiPostVectorizeRequest) OutputEpsVersion

func (r ApiPostVectorizeRequest) OutputEpsVersion(outputEpsVersion string) ApiPostVectorizeRequest

EPS format version for EPS output.

func (ApiPostVectorizeRequest) OutputFileFormat

func (r ApiPostVectorizeRequest) OutputFileFormat(outputFileFormat string) ApiPostVectorizeRequest

Output file format to generate.

func (ApiPostVectorizeRequest) OutputGapFillerClip

func (r ApiPostVectorizeRequest) OutputGapFillerClip(outputGapFillerClip bool) ApiPostVectorizeRequest

Clip gap filler strokes to shape bounds when stacking shapes.

func (ApiPostVectorizeRequest) OutputGapFillerEnabled

func (r ApiPostVectorizeRequest) OutputGapFillerEnabled(outputGapFillerEnabled bool) ApiPostVectorizeRequest

Enable filling small visual gaps caused by vector rendering artifacts.

func (ApiPostVectorizeRequest) OutputGapFillerNonScalingStroke

func (r ApiPostVectorizeRequest) OutputGapFillerNonScalingStroke(outputGapFillerNonScalingStroke bool) ApiPostVectorizeRequest

Use non-scaling strokes for gap filling.

func (ApiPostVectorizeRequest) OutputGapFillerStrokeWidth

func (r ApiPostVectorizeRequest) OutputGapFillerStrokeWidth(outputGapFillerStrokeWidth float32) ApiPostVectorizeRequest

Width of the gap filler strokes (in output units).

func (ApiPostVectorizeRequest) OutputGroupBy

func (r ApiPostVectorizeRequest) OutputGroupBy(outputGroupBy string) ApiPostVectorizeRequest

Grouping of shapes in output.

func (ApiPostVectorizeRequest) OutputParameterizedShapesFlatten

func (r ApiPostVectorizeRequest) OutputParameterizedShapesFlatten(outputParameterizedShapesFlatten bool) ApiPostVectorizeRequest

Whether to flatten detected circles, rectangles, and stars to curves.

func (ApiPostVectorizeRequest) OutputPdfCompressionMode

func (r ApiPostVectorizeRequest) OutputPdfCompressionMode(outputPdfCompressionMode string) ApiPostVectorizeRequest

Compression method to apply to PDF output streams.

func (ApiPostVectorizeRequest) OutputPdfVersion

func (r ApiPostVectorizeRequest) OutputPdfVersion(outputPdfVersion string) ApiPostVectorizeRequest

PDF version to generate for PDF output.

func (ApiPostVectorizeRequest) OutputShapeStacking

func (r ApiPostVectorizeRequest) OutputShapeStacking(outputShapeStacking string) ApiPostVectorizeRequest

Whether shapes are cut out of each other or stacked atop each other.

func (ApiPostVectorizeRequest) OutputSizeAlignX

func (r ApiPostVectorizeRequest) OutputSizeAlignX(outputSizeAlignX float32) ApiPostVectorizeRequest

Horizontal alignment (0.0 = left, 0.5 = center, 1.0 = right) when aspect ratio is preserved.

func (ApiPostVectorizeRequest) OutputSizeAlignY

func (r ApiPostVectorizeRequest) OutputSizeAlignY(outputSizeAlignY float32) ApiPostVectorizeRequest

Vertical alignment (0.0 = top, 0.5 = center, 1.0 = bottom) when aspect ratio is preserved.

func (ApiPostVectorizeRequest) OutputSizeAspectRatio

func (r ApiPostVectorizeRequest) OutputSizeAspectRatio(outputSizeAspectRatio string) ApiPostVectorizeRequest

How to preserve or stretch aspect ratio.

func (ApiPostVectorizeRequest) OutputSizeHeight

func (r ApiPostVectorizeRequest) OutputSizeHeight(outputSizeHeight float32) ApiPostVectorizeRequest

Output height, in the selected unit (see output.size.unit).

func (ApiPostVectorizeRequest) OutputSizeInputDpi

func (r ApiPostVectorizeRequest) OutputSizeInputDpi(outputSizeInputDpi float32) ApiPostVectorizeRequest

Override the detected DPI of the input image for size computations.

func (ApiPostVectorizeRequest) OutputSizeOutputDpi

func (r ApiPostVectorizeRequest) OutputSizeOutputDpi(outputSizeOutputDpi float32) ApiPostVectorizeRequest

DPI setting for the output image.

func (ApiPostVectorizeRequest) OutputSizeScale

func (r ApiPostVectorizeRequest) OutputSizeScale(outputSizeScale float32) ApiPostVectorizeRequest

Overall uniform scaling factor for the output image.

func (ApiPostVectorizeRequest) OutputSizeUnit

func (r ApiPostVectorizeRequest) OutputSizeUnit(outputSizeUnit string) ApiPostVectorizeRequest

Measurement unit for output dimensions.

func (ApiPostVectorizeRequest) OutputSizeWidth

func (r ApiPostVectorizeRequest) OutputSizeWidth(outputSizeWidth float32) ApiPostVectorizeRequest

Output width, in the selected unit (see output.size.unit).

func (ApiPostVectorizeRequest) OutputStrokesNonScalingStroke

func (r ApiPostVectorizeRequest) OutputStrokesNonScalingStroke(outputStrokesNonScalingStroke bool) ApiPostVectorizeRequest

Use non-scaling strokes when drawing shape outlines.

func (ApiPostVectorizeRequest) OutputStrokesOverrideColor

func (r ApiPostVectorizeRequest) OutputStrokesOverrideColor(outputStrokesOverrideColor string) ApiPostVectorizeRequest

Color value to override shape stroke color if enabled. Must be in '#RRGGBB' or 'rgba(r,g,b,a)' format.

func (ApiPostVectorizeRequest) OutputStrokesStrokeWidth

func (r ApiPostVectorizeRequest) OutputStrokesStrokeWidth(outputStrokesStrokeWidth float32) ApiPostVectorizeRequest

Width of stroke for shape outlines (when enabled).

func (ApiPostVectorizeRequest) OutputStrokesUseOverrideColor

func (r ApiPostVectorizeRequest) OutputStrokesUseOverrideColor(outputStrokesUseOverrideColor bool) ApiPostVectorizeRequest

Override shape color with a specific color.

func (ApiPostVectorizeRequest) OutputSvgAdobeCompatibilityMode

func (r ApiPostVectorizeRequest) OutputSvgAdobeCompatibilityMode(outputSvgAdobeCompatibilityMode bool) ApiPostVectorizeRequest

Enable Illustrator compatibility by disabling unsupported SVG features.

func (ApiPostVectorizeRequest) OutputSvgFixedSize

func (r ApiPostVectorizeRequest) OutputSvgFixedSize(outputSvgFixedSize bool) ApiPostVectorizeRequest

Whether to fix the SVG dimensions in the output file.

func (ApiPostVectorizeRequest) OutputSvgVersion

func (r ApiPostVectorizeRequest) OutputSvgVersion(outputSvgVersion string) ApiPostVectorizeRequest

SVG version to declare in the SVG output.

func (ApiPostVectorizeRequest) PolicyRetentionDays

func (r ApiPostVectorizeRequest) PolicyRetentionDays(policyRetentionDays int32) ApiPostVectorizeRequest

Number of days to retain the uploaded image and its results for re-use.

func (ApiPostVectorizeRequest) ProcessingColorProfileInput

func (r ApiPostVectorizeRequest) ProcessingColorProfileInput(processingColorProfileInput string) ApiPostVectorizeRequest

How to handle ICC profiles embedded in input images.

func (ApiPostVectorizeRequest) ProcessingColorProfileOutput

func (r ApiPostVectorizeRequest) ProcessingColorProfileOutput(processingColorProfileOutput string) ApiPostVectorizeRequest

ICC profile behavior for output files: preserve, ignore.

func (ApiPostVectorizeRequest) ProcessingMaxColors

func (r ApiPostVectorizeRequest) ProcessingMaxColors(processingMaxColors int32) ApiPostVectorizeRequest

Maximum number of colors allowed in the vectorization result. 0 means unlimited.

func (ApiPostVectorizeRequest) ProcessingPalette

func (r ApiPostVectorizeRequest) ProcessingPalette(processingPalette string) ApiPostVectorizeRequest

Palette remapping and color control, using '[color][-> remapped][~ tolerance];' format.

func (ApiPostVectorizeRequest) ProcessingParameterizedShapesEllipseCircleEnabled

func (r ApiPostVectorizeRequest) ProcessingParameterizedShapesEllipseCircleEnabled(processingParameterizedShapesEllipseCircleEnabled bool) ApiPostVectorizeRequest

Enable detection and parameterization of this parameterized shape type.

func (ApiPostVectorizeRequest) ProcessingParameterizedShapesEllipseGeneralEnabled

func (r ApiPostVectorizeRequest) ProcessingParameterizedShapesEllipseGeneralEnabled(processingParameterizedShapesEllipseGeneralEnabled bool) ApiPostVectorizeRequest

Enable detection and parameterization of this parameterized shape type.

func (ApiPostVectorizeRequest) ProcessingParameterizedShapesQuadrilateralBulletEnabled

func (r ApiPostVectorizeRequest) ProcessingParameterizedShapesQuadrilateralBulletEnabled(processingParameterizedShapesQuadrilateralBulletEnabled bool) ApiPostVectorizeRequest

Enable detection and parameterization of this parameterized shape type.

func (ApiPostVectorizeRequest) ProcessingParameterizedShapesQuadrilateralGeneralEnabled

func (r ApiPostVectorizeRequest) ProcessingParameterizedShapesQuadrilateralGeneralEnabled(processingParameterizedShapesQuadrilateralGeneralEnabled bool) ApiPostVectorizeRequest

Enable detection and parameterization of this parameterized shape type.

func (ApiPostVectorizeRequest) ProcessingParameterizedShapesQuadrilateralRectangleEnabled

func (r ApiPostVectorizeRequest) ProcessingParameterizedShapesQuadrilateralRectangleEnabled(processingParameterizedShapesQuadrilateralRectangleEnabled bool) ApiPostVectorizeRequest

Enable detection and parameterization of this parameterized shape type.

func (ApiPostVectorizeRequest) ProcessingParameterizedShapesStarN3Enabled

func (r ApiPostVectorizeRequest) ProcessingParameterizedShapesStarN3Enabled(processingParameterizedShapesStarN3Enabled bool) ApiPostVectorizeRequest

Enable detection and parameterization of this parameterized shape type.

func (ApiPostVectorizeRequest) ProcessingParameterizedShapesStarN4Enabled

func (r ApiPostVectorizeRequest) ProcessingParameterizedShapesStarN4Enabled(processingParameterizedShapesStarN4Enabled bool) ApiPostVectorizeRequest

Enable detection and parameterization of this parameterized shape type.

func (ApiPostVectorizeRequest) ProcessingParameterizedShapesStarN5Enabled

func (r ApiPostVectorizeRequest) ProcessingParameterizedShapesStarN5Enabled(processingParameterizedShapesStarN5Enabled bool) ApiPostVectorizeRequest

Enable detection and parameterization of this parameterized shape type.

func (ApiPostVectorizeRequest) ProcessingParameterizedShapesStarN6Enabled

func (r ApiPostVectorizeRequest) ProcessingParameterizedShapesStarN6Enabled(processingParameterizedShapesStarN6Enabled bool) ApiPostVectorizeRequest

Enable detection and parameterization of this parameterized shape type.

func (ApiPostVectorizeRequest) ProcessingParameterizedShapesTriangleGeneralEnabled

func (r ApiPostVectorizeRequest) ProcessingParameterizedShapesTriangleGeneralEnabled(processingParameterizedShapesTriangleGeneralEnabled bool) ApiPostVectorizeRequest

Enable detection and parameterization of this parameterized shape type.

func (ApiPostVectorizeRequest) ProcessingParameterizedShapesTriangleIsoscelesEnabled

func (r ApiPostVectorizeRequest) ProcessingParameterizedShapesTriangleIsoscelesEnabled(processingParameterizedShapesTriangleIsoscelesEnabled bool) ApiPostVectorizeRequest

Enable detection and parameterization of this parameterized shape type.

func (ApiPostVectorizeRequest) ProcessingShapesMinAreaPx

func (r ApiPostVectorizeRequest) ProcessingShapesMinAreaPx(processingShapesMinAreaPx float32) ApiPostVectorizeRequest

Minimum shape area (in pixels) to keep in the result; smaller shapes are discarded.

type BasicAuth

type BasicAuth struct {
	UserName string `json:"userName,omitempty"`
	Password string `json:"password,omitempty"`
}

BasicAuth provides basic http authentication to a request passed via context using ContextBasicAuth

type Configuration

type Configuration struct {
	Host             string            `json:"host,omitempty"`
	Scheme           string            `json:"scheme,omitempty"`
	DefaultHeader    map[string]string `json:"defaultHeader,omitempty"`
	UserAgent        string            `json:"userAgent,omitempty"`
	Debug            bool              `json:"debug,omitempty"`
	Servers          ServerConfigurations
	OperationServers map[string]ServerConfigurations
	HTTPClient       *http.Client
}

Configuration stores the configuration of the API client

func NewConfiguration

func NewConfiguration() *Configuration

NewConfiguration returns a new Configuration object

func (*Configuration) AddDefaultHeader

func (c *Configuration) AddDefaultHeader(key string, value string)

AddDefaultHeader adds a new HTTP header to the default header in the request

func (*Configuration) ServerURL

func (c *Configuration) ServerURL(index int, variables map[string]string) (string, error)

ServerURL returns URL based on server settings

func (*Configuration) ServerURLWithContext

func (c *Configuration) ServerURLWithContext(ctx context.Context, endpoint string) (string, error)

ServerURLWithContext returns a new server URL given an endpoint

type DeleteImageResponse

type DeleteImageResponse struct {
	// Always true when the Image Token has been deleted.
	Success bool `json:"success"`
}

DeleteImageResponse struct for DeleteImageResponse

func NewDeleteImageResponse

func NewDeleteImageResponse(success bool) *DeleteImageResponse

NewDeleteImageResponse instantiates a new DeleteImageResponse object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewDeleteImageResponseWithDefaults

func NewDeleteImageResponseWithDefaults() *DeleteImageResponse

NewDeleteImageResponseWithDefaults instantiates a new DeleteImageResponse object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*DeleteImageResponse) GetSuccess

func (o *DeleteImageResponse) GetSuccess() bool

GetSuccess returns the Success field value

func (*DeleteImageResponse) GetSuccessOk

func (o *DeleteImageResponse) GetSuccessOk() (*bool, bool)

GetSuccessOk returns a tuple with the Success field value and a boolean to check if the value has been set.

func (DeleteImageResponse) MarshalJSON

func (o DeleteImageResponse) MarshalJSON() ([]byte, error)

func (*DeleteImageResponse) SetSuccess

func (o *DeleteImageResponse) SetSuccess(v bool)

SetSuccess sets field value

func (DeleteImageResponse) ToMap

func (o DeleteImageResponse) ToMap() (map[string]interface{}, error)

func (*DeleteImageResponse) UnmarshalJSON

func (o *DeleteImageResponse) UnmarshalJSON(data []byte) (err error)

type ErrorResponse

type ErrorResponse struct {
	Error ErrorResponseError `json:"error"`
	// Echo of the submitted request data when available. File uploads are summarized instead of echoed.
	DataReceived map[string]interface{} `json:"dataReceived"`
}

ErrorResponse struct for ErrorResponse

func NewErrorResponse

func NewErrorResponse(error_ ErrorResponseError, dataReceived map[string]interface{}) *ErrorResponse

NewErrorResponse instantiates a new ErrorResponse object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewErrorResponseWithDefaults

func NewErrorResponseWithDefaults() *ErrorResponse

NewErrorResponseWithDefaults instantiates a new ErrorResponse object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*ErrorResponse) GetDataReceived

func (o *ErrorResponse) GetDataReceived() map[string]interface{}

GetDataReceived returns the DataReceived field value If the value is explicit nil, the zero value for map[string]interface{} will be returned

func (*ErrorResponse) GetDataReceivedOk

func (o *ErrorResponse) GetDataReceivedOk() (map[string]interface{}, bool)

GetDataReceivedOk returns a tuple with the DataReceived field value and a boolean to check if the value has been set. NOTE: If the value is an explicit nil, `nil, true` will be returned

func (*ErrorResponse) GetError

func (o *ErrorResponse) GetError() ErrorResponseError

GetError returns the Error field value

func (*ErrorResponse) GetErrorOk

func (o *ErrorResponse) GetErrorOk() (*ErrorResponseError, bool)

GetErrorOk returns a tuple with the Error field value and a boolean to check if the value has been set.

func (ErrorResponse) MarshalJSON

func (o ErrorResponse) MarshalJSON() ([]byte, error)

func (*ErrorResponse) SetDataReceived

func (o *ErrorResponse) SetDataReceived(v map[string]interface{})

SetDataReceived sets field value

func (*ErrorResponse) SetError

func (o *ErrorResponse) SetError(v ErrorResponseError)

SetError sets field value

func (ErrorResponse) ToMap

func (o ErrorResponse) ToMap() (map[string]interface{}, error)

func (*ErrorResponse) UnmarshalJSON

func (o *ErrorResponse) UnmarshalJSON(data []byte) (err error)

type ErrorResponseError

type ErrorResponseError struct {
	Status  int32  `json:"status"`
	Code    int32  `json:"code"`
	Message string `json:"message"`
}

ErrorResponseError struct for ErrorResponseError

func NewErrorResponseError

func NewErrorResponseError(status int32, code int32, message string) *ErrorResponseError

NewErrorResponseError instantiates a new ErrorResponseError object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewErrorResponseErrorWithDefaults

func NewErrorResponseErrorWithDefaults() *ErrorResponseError

NewErrorResponseErrorWithDefaults instantiates a new ErrorResponseError object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*ErrorResponseError) GetCode

func (o *ErrorResponseError) GetCode() int32

GetCode returns the Code field value

func (*ErrorResponseError) GetCodeOk

func (o *ErrorResponseError) GetCodeOk() (*int32, bool)

GetCodeOk returns a tuple with the Code field value and a boolean to check if the value has been set.

func (*ErrorResponseError) GetMessage

func (o *ErrorResponseError) GetMessage() string

GetMessage returns the Message field value

func (*ErrorResponseError) GetMessageOk

func (o *ErrorResponseError) GetMessageOk() (*string, bool)

GetMessageOk returns a tuple with the Message field value and a boolean to check if the value has been set.

func (*ErrorResponseError) GetStatus

func (o *ErrorResponseError) GetStatus() int32

GetStatus returns the Status field value

func (*ErrorResponseError) GetStatusOk

func (o *ErrorResponseError) GetStatusOk() (*int32, bool)

GetStatusOk returns a tuple with the Status field value and a boolean to check if the value has been set.

func (ErrorResponseError) MarshalJSON

func (o ErrorResponseError) MarshalJSON() ([]byte, error)

func (*ErrorResponseError) SetCode

func (o *ErrorResponseError) SetCode(v int32)

SetCode sets field value

func (*ErrorResponseError) SetMessage

func (o *ErrorResponseError) SetMessage(v string)

SetMessage sets field value

func (*ErrorResponseError) SetStatus

func (o *ErrorResponseError) SetStatus(v int32)

SetStatus sets field value

func (ErrorResponseError) ToMap

func (o ErrorResponseError) ToMap() (map[string]interface{}, error)

func (*ErrorResponseError) UnmarshalJSON

func (o *ErrorResponseError) UnmarshalJSON(data []byte) (err error)

type GenericOpenAPIError

type GenericOpenAPIError struct {
	// contains filtered or unexported fields
}

GenericOpenAPIError Provides access to the body, error and model on returned errors.

func (GenericOpenAPIError) Body

func (e GenericOpenAPIError) Body() []byte

Body returns the raw bytes of the response

func (GenericOpenAPIError) Error

func (e GenericOpenAPIError) Error() string

Error returns non-empty string if there was an error.

func (GenericOpenAPIError) Model

func (e GenericOpenAPIError) Model() interface{}

Model returns the unpacked model of the error

type MappedNullable

type MappedNullable interface {
	ToMap() (map[string]interface{}, error)
}

type NullableAccountStatusResponse

type NullableAccountStatusResponse struct {
	// contains filtered or unexported fields
}

func (NullableAccountStatusResponse) Get

func (NullableAccountStatusResponse) IsSet

func (NullableAccountStatusResponse) MarshalJSON

func (v NullableAccountStatusResponse) MarshalJSON() ([]byte, error)

func (*NullableAccountStatusResponse) Set

func (*NullableAccountStatusResponse) UnmarshalJSON

func (v *NullableAccountStatusResponse) UnmarshalJSON(src []byte) error

func (*NullableAccountStatusResponse) Unset

func (v *NullableAccountStatusResponse) Unset()

type NullableBool

type NullableBool struct {
	// contains filtered or unexported fields
}

func NewNullableBool

func NewNullableBool(val *bool) *NullableBool

func (NullableBool) Get

func (v NullableBool) Get() *bool

func (NullableBool) IsSet

func (v NullableBool) IsSet() bool

func (NullableBool) MarshalJSON

func (v NullableBool) MarshalJSON() ([]byte, error)

func (*NullableBool) Set

func (v *NullableBool) Set(val *bool)

func (*NullableBool) UnmarshalJSON

func (v *NullableBool) UnmarshalJSON(src []byte) error

func (*NullableBool) Unset

func (v *NullableBool) Unset()

type NullableDeleteImageResponse

type NullableDeleteImageResponse struct {
	// contains filtered or unexported fields
}

func NewNullableDeleteImageResponse

func NewNullableDeleteImageResponse(val *DeleteImageResponse) *NullableDeleteImageResponse

func (NullableDeleteImageResponse) Get

func (NullableDeleteImageResponse) IsSet

func (NullableDeleteImageResponse) MarshalJSON

func (v NullableDeleteImageResponse) MarshalJSON() ([]byte, error)

func (*NullableDeleteImageResponse) Set

func (*NullableDeleteImageResponse) UnmarshalJSON

func (v *NullableDeleteImageResponse) UnmarshalJSON(src []byte) error

func (*NullableDeleteImageResponse) Unset

func (v *NullableDeleteImageResponse) Unset()

type NullableErrorResponse

type NullableErrorResponse struct {
	// contains filtered or unexported fields
}

func NewNullableErrorResponse

func NewNullableErrorResponse(val *ErrorResponse) *NullableErrorResponse

func (NullableErrorResponse) Get

func (NullableErrorResponse) IsSet

func (v NullableErrorResponse) IsSet() bool

func (NullableErrorResponse) MarshalJSON

func (v NullableErrorResponse) MarshalJSON() ([]byte, error)

func (*NullableErrorResponse) Set

func (v *NullableErrorResponse) Set(val *ErrorResponse)

func (*NullableErrorResponse) UnmarshalJSON

func (v *NullableErrorResponse) UnmarshalJSON(src []byte) error

func (*NullableErrorResponse) Unset

func (v *NullableErrorResponse) Unset()

type NullableErrorResponseError

type NullableErrorResponseError struct {
	// contains filtered or unexported fields
}

func NewNullableErrorResponseError

func NewNullableErrorResponseError(val *ErrorResponseError) *NullableErrorResponseError

func (NullableErrorResponseError) Get

func (NullableErrorResponseError) IsSet

func (v NullableErrorResponseError) IsSet() bool

func (NullableErrorResponseError) MarshalJSON

func (v NullableErrorResponseError) MarshalJSON() ([]byte, error)

func (*NullableErrorResponseError) Set

func (*NullableErrorResponseError) UnmarshalJSON

func (v *NullableErrorResponseError) UnmarshalJSON(src []byte) error

func (*NullableErrorResponseError) Unset

func (v *NullableErrorResponseError) Unset()

type NullableFloat32

type NullableFloat32 struct {
	// contains filtered or unexported fields
}

func NewNullableFloat32

func NewNullableFloat32(val *float32) *NullableFloat32

func (NullableFloat32) Get

func (v NullableFloat32) Get() *float32

func (NullableFloat32) IsSet

func (v NullableFloat32) IsSet() bool

func (NullableFloat32) MarshalJSON

func (v NullableFloat32) MarshalJSON() ([]byte, error)

func (*NullableFloat32) Set

func (v *NullableFloat32) Set(val *float32)

func (*NullableFloat32) UnmarshalJSON

func (v *NullableFloat32) UnmarshalJSON(src []byte) error

func (*NullableFloat32) Unset

func (v *NullableFloat32) Unset()

type NullableFloat64

type NullableFloat64 struct {
	// contains filtered or unexported fields
}

func NewNullableFloat64

func NewNullableFloat64(val *float64) *NullableFloat64

func (NullableFloat64) Get

func (v NullableFloat64) Get() *float64

func (NullableFloat64) IsSet

func (v NullableFloat64) IsSet() bool

func (NullableFloat64) MarshalJSON

func (v NullableFloat64) MarshalJSON() ([]byte, error)

func (*NullableFloat64) Set

func (v *NullableFloat64) Set(val *float64)

func (*NullableFloat64) UnmarshalJSON

func (v *NullableFloat64) UnmarshalJSON(src []byte) error

func (*NullableFloat64) Unset

func (v *NullableFloat64) Unset()

type NullableInt

type NullableInt struct {
	// contains filtered or unexported fields
}

func NewNullableInt

func NewNullableInt(val *int) *NullableInt

func (NullableInt) Get

func (v NullableInt) Get() *int

func (NullableInt) IsSet

func (v NullableInt) IsSet() bool

func (NullableInt) MarshalJSON

func (v NullableInt) MarshalJSON() ([]byte, error)

func (*NullableInt) Set

func (v *NullableInt) Set(val *int)

func (*NullableInt) UnmarshalJSON

func (v *NullableInt) UnmarshalJSON(src []byte) error

func (*NullableInt) Unset

func (v *NullableInt) Unset()

type NullableInt32

type NullableInt32 struct {
	// contains filtered or unexported fields
}

func NewNullableInt32

func NewNullableInt32(val *int32) *NullableInt32

func (NullableInt32) Get

func (v NullableInt32) Get() *int32

func (NullableInt32) IsSet

func (v NullableInt32) IsSet() bool

func (NullableInt32) MarshalJSON

func (v NullableInt32) MarshalJSON() ([]byte, error)

func (*NullableInt32) Set

func (v *NullableInt32) Set(val *int32)

func (*NullableInt32) UnmarshalJSON

func (v *NullableInt32) UnmarshalJSON(src []byte) error

func (*NullableInt32) Unset

func (v *NullableInt32) Unset()

type NullableInt64

type NullableInt64 struct {
	// contains filtered or unexported fields
}

func NewNullableInt64

func NewNullableInt64(val *int64) *NullableInt64

func (NullableInt64) Get

func (v NullableInt64) Get() *int64

func (NullableInt64) IsSet

func (v NullableInt64) IsSet() bool

func (NullableInt64) MarshalJSON

func (v NullableInt64) MarshalJSON() ([]byte, error)

func (*NullableInt64) Set

func (v *NullableInt64) Set(val *int64)

func (*NullableInt64) UnmarshalJSON

func (v *NullableInt64) UnmarshalJSON(src []byte) error

func (*NullableInt64) Unset

func (v *NullableInt64) Unset()

type NullableString

type NullableString struct {
	// contains filtered or unexported fields
}

func NewNullableString

func NewNullableString(val *string) *NullableString

func (NullableString) Get

func (v NullableString) Get() *string

func (NullableString) IsSet

func (v NullableString) IsSet() bool

func (NullableString) MarshalJSON

func (v NullableString) MarshalJSON() ([]byte, error)

func (*NullableString) Set

func (v *NullableString) Set(val *string)

func (*NullableString) UnmarshalJSON

func (v *NullableString) UnmarshalJSON(src []byte) error

func (*NullableString) Unset

func (v *NullableString) Unset()

type NullableTime

type NullableTime struct {
	// contains filtered or unexported fields
}

func NewNullableTime

func NewNullableTime(val *time.Time) *NullableTime

func (NullableTime) Get

func (v NullableTime) Get() *time.Time

func (NullableTime) IsSet

func (v NullableTime) IsSet() bool

func (NullableTime) MarshalJSON

func (v NullableTime) MarshalJSON() ([]byte, error)

func (*NullableTime) Set

func (v *NullableTime) Set(val *time.Time)

func (*NullableTime) UnmarshalJSON

func (v *NullableTime) UnmarshalJSON(src []byte) error

func (*NullableTime) Unset

func (v *NullableTime) Unset()

type ServerConfiguration

type ServerConfiguration struct {
	URL         string
	Description string
	Variables   map[string]ServerVariable
}

ServerConfiguration stores the information about a server

type ServerConfigurations

type ServerConfigurations []ServerConfiguration

ServerConfigurations stores multiple ServerConfiguration items

func (ServerConfigurations) URL

func (sc ServerConfigurations) URL(index int, variables map[string]string) (string, error)

URL formats template on a index using given variables

type ServerVariable

type ServerVariable struct {
	Description  string
	DefaultValue string
	EnumValues   []string
}

ServerVariable stores the information about a server variable

type VectorizationAPIService

type VectorizationAPIService service

VectorizationAPIService VectorizationAPI service

func (*VectorizationAPIService) PostDelete

PostDelete Delete a retained image

Delete a retained image and result before its retention period expires.

@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
@return ApiPostDeleteRequest

func (*VectorizationAPIService) PostDeleteExecute

Execute executes the request

@return DeleteImageResponse

func (*VectorizationAPIService) PostDownload

PostDownload Download a retained result

Download a production result from a retained Image Token, optionally changing output.file_format and other output options. Include receipt when downloading additional formats after upgrading a preview result.

@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
@return ApiPostDownloadRequest

func (*VectorizationAPIService) PostDownloadExecute

func (a *VectorizationAPIService) PostDownloadExecute(r ApiPostDownloadRequest) (*os.File, *http.Response, error)

Execute executes the request

@return *os.File

func (*VectorizationAPIService) PostVectorize

PostVectorize Vectorize an image

Submit exactly one image source as multipart form data: image, image.url, image.base64, or image.token. The response body is the generated SVG, EPS, PDF, DXF, or PNG file selected by output.file_format. Clients should allow an idle timeout of at least 180 seconds.

@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
@return ApiPostVectorizeRequest

func (*VectorizationAPIService) PostVectorizeExecute

func (a *VectorizationAPIService) PostVectorizeExecute(r ApiPostVectorizeRequest) (*os.File, *http.Response, error)

Execute executes the request

@return *os.File

Jump to